==> aws-cdk-lib-2.223.0-sources.jar: software/amazon/awscdk/services/macie/CfnSessionProps.java <==
package software.amazon.awscdk.services.macie;

/**
 * Properties for defining a <code>CfnSession</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.macie.*;
 * CfnSessionProps cfnSessionProps = CfnSessionProps.builder()
 *         .findingPublishingFrequency("findingPublishingFrequency")
 *         .status("status")
 *         .build();
 * </pre></blockquote>
 * <p>
 * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.118.0 (build 02eec31)", date = "2025-11-10T13:40:09.480Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_macie.CfnSessionProps")
@software.amazon.jsii.Jsii.Proxy(CfnSessionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnSessionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Specifies how often Amazon Macie publishes updates to policy findings for the account.
     * <p>
     * This includes publishing updates to AWS Security Hub and Amazon EventBridge (formerly Amazon CloudWatch Events ). Valid values are:
     * <p>
     * <ul>
     * <li>FIFTEEN_MINUTES</li>
     * <li>ONE_HOUR</li>
     * <li>SIX_HOURS</li>
     * </ul>
     * <p>
     * Default: - "SIX_HOURS"
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html#cfn-macie-session-findingpublishingfrequency">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html#cfn-macie-session-findingpublishingfrequency</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getFindingPublishingFrequency() {
        return null;
    }

    /**
     * The status of Amazon Macie for the account.
     * <p>
     * Valid values are: <code>ENABLED</code> , start or resume Macie activities for the account; and, <code>PAUSED</code> , suspend Macie activities for the account.
     * <p>
     * Default: - "ENABLED"
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html#cfn-macie-session-status">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html#cfn-macie-session-status</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getStatus() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnSessionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnSessionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnSessionProps> {
        java.lang.String findingPublishingFrequency;
        java.lang.String status;

        /**
         * Sets the value of {@link CfnSessionProps#getFindingPublishingFrequency}
         * @param findingPublishingFrequency Specifies how often Amazon Macie publishes updates to policy findings for the account.
         *                                   This includes publishing updates to AWS Security Hub and Amazon EventBridge (formerly Amazon CloudWatch Events ). Valid values are:
         *                                   <p>
         *                                   <ul>
         *                                   <li>FIFTEEN_MINUTES</li>
         *                                   <li>ONE_HOUR</li>
         *                                   <li>SIX_HOURS</li>
         *                                   </ul>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder findingPublishingFrequency(java.lang.String findingPublishingFrequency) {
            this.findingPublishingFrequency = findingPublishingFrequency;
            return this;
        }

        /**
         * Sets the value of {@link CfnSessionProps#getStatus}
         * @param status The status of Amazon Macie for the account.
         *               Valid values are: <code>ENABLED</code> , start or resume Macie activities for the account; and, <code>PAUSED</code> , suspend Macie activities for the account.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder status(java.lang.String status) {
            this.status = status;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnSessionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnSessionProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnSessionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnSessionProps {
        private final java.lang.String findingPublishingFrequency;
        private final java.lang.String status;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.findingPublishingFrequency = software.amazon.jsii.Kernel.get(this, "findingPublishingFrequency", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.status = software.amazon.jsii.Kernel.get(this, "status", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.findingPublishingFrequency = builder.findingPublishingFrequency;
            this.status = builder.status;
        }

        @Override
        public final java.lang.String getFindingPublishingFrequency() {
            return this.findingPublishingFrequency;
        }

        @Override
        public final java.lang.String getStatus() {
            return this.status;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getFindingPublishingFrequency() != null) {
                data.set("findingPublishingFrequency", om.valueToTree(this.getFindingPublishingFrequency()));
            }
            if (this.getStatus() != null) {
                data.set("status", om.valueToTree(this.getStatus()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_macie.CfnSessionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnSessionProps.Jsii$Proxy that = (CfnSessionProps.Jsii$Proxy) o;

            if (this.findingPublishingFrequency != null ? !this.findingPublishingFrequency.equals(that.findingPublishingFrequency) : that.findingPublishingFrequency != null) return false;
            return this.status != null ? this.status.equals(that.status) : that.status == null;
        }

        @Override
        public final int hashCode() {
            int result = this.findingPublishingFrequency != null ? this.findingPublishingFrequency.hashCode() : 0;
            result = 31 * result + (this.status != null ? this.status.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.225.0-sources.jar: software/amazon/awscdk/services/macie/CfnSessionProps.java <==
package software.amazon.awscdk.services.macie;

/**
 * Properties for defining a <code>CfnSession</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.macie.*;
 * CfnSessionProps cfnSessionProps = CfnSessionProps.builder()
 *         .findingPublishingFrequency("findingPublishingFrequency")
 *         .status("status")
 *         .build();
 * </pre></blockquote>
 * <p>
 * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-11-17T14:40:55.521Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_macie.CfnSessionProps")
@software.amazon.jsii.Jsii.Proxy(CfnSessionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnSessionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Specifies how often Amazon Macie publishes updates to policy findings for the account.
     * <p>
     * This includes publishing updates to Security Hub and Amazon EventBridge (formerly Amazon CloudWatch Events ). Valid values are:
     * <p>
     * <ul>
     * <li>FIFTEEN_MINUTES</li>
     * <li>ONE_HOUR</li>
     * <li>SIX_HOURS</li>
     * </ul>
     * <p>
     * Default: - "SIX_HOURS"
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html#cfn-macie-session-findingpublishingfrequency">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html#cfn-macie-session-findingpublishingfrequency</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getFindingPublishingFrequency() {
        return null;
    }

    /**
     * The status of Amazon Macie for the account.
     * <p>
     * Valid values are: <code>ENABLED</code> , start or resume Macie activities for the account; and, <code>PAUSED</code> , suspend Macie activities for the account.
     * <p>
     * Default: - "ENABLED"
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html#cfn-macie-session-status">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-macie-session.html#cfn-macie-session-status</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getStatus() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnSessionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnSessionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnSessionProps> {
        java.lang.String findingPublishingFrequency;
        java.lang.String status;

        /**
         * Sets the value of {@link CfnSessionProps#getFindingPublishingFrequency}
         * @param findingPublishingFrequency Specifies how often Amazon Macie publishes updates to policy findings for the account.
         *                                   This includes publishing updates to Security Hub and Amazon EventBridge (formerly Amazon CloudWatch Events ). Valid values are:
         *                                   <p>
         *                                   <ul>
         *                                   <li>FIFTEEN_MINUTES</li>
         *                                   <li>ONE_HOUR</li>
         *                                   <li>SIX_HOURS</li>
         *                                   </ul>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder findingPublishingFrequency(java.lang.String findingPublishingFrequency) {
            this.findingPublishingFrequency = findingPublishingFrequency;
            return this;
        }

        /**
         * Sets the value of {@link CfnSessionProps#getStatus}
         * @param status The status of Amazon Macie for the account.
         *               Valid values are: <code>ENABLED</code> , start or resume Macie activities for the account; and, <code>PAUSED</code> , suspend Macie activities for the account.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder status(java.lang.String status) {
            this.status = status;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnSessionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnSessionProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnSessionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnSessionProps {
        private final java.lang.String findingPublishingFrequency;
        private final java.lang.String status;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.findingPublishingFrequency = software.amazon.jsii.Kernel.get(this, "findingPublishingFrequency", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.status = software.amazon.jsii.Kernel.get(this, "status", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.findingPublishingFrequency = builder.findingPublishingFrequency;
            this.status = builder.status;
        }

        @Override
        public final java.lang.String getFindingPublishingFrequency() {
            return this.findingPublishingFrequency;
        }

        @Override
        public final java.lang.String getStatus() {
            return this.status;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getFindingPublishingFrequency() != null) {
                data.set("findingPublishingFrequency", om.valueToTree(this.getFindingPublishingFrequency()));
            }
            if (this.getStatus() != null) {
                data.set("status", om.valueToTree(this.getStatus()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_macie.CfnSessionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnSessionProps.Jsii$Proxy that = (CfnSessionProps.Jsii$Proxy) o;

            if (this.findingPublishingFrequency != null ? !this.findingPublishingFrequency.equals(that.findingPublishingFrequency) : that.findingPublishingFrequency != null) return false;
            return this.status != null ? this.status.equals(that.status) : that.status == null;
        }

        @Override
        public final int hashCode() {
            int result = this.findingPublishingFrequency != null ? this.findingPublishingFrequency.hashCode() : 0;
            result = 31 * result + (this.status != null ? this.status.hashCode() : 0);
            return result;
        }
    }
}
